@@ -26,6 +26,22 @@ using namespace Qt::StringLiterals;
 
 // abstractmetabuilder.cpp
 
+static QTextStream &operator<<(QTextStream &s, Access a)
+{
+    switch (a) {
+    case Access::Public:
+        s << "public";
+        break;
+    case Access::Protected:
+        s << "protected";
+        break;
+    case Access::Private:
+        s << "private";
+        break;
+    }
+    return s;
+}
+
 QString msgNoFunctionForModification(const AbstractMetaClassCPtr &klass,
                                      const QString &signature,
                                      const QString &originalSignature,
@@ -301,11 +317,13 @@ QString msgSkippingFunction(const FunctionModelItem &functionItem,
 {
     QString result;
     QTextStream str(&result);
-    str << functionItem->sourceLocation() << "skipping ";
-    if (functionItem->isAbstract())
+    str << functionItem->sourceLocation() << "skipping "
+        << functionItem->accessPolicy() << ' ';
+    const bool isAbstract = functionItem->attributes().testFlag(FunctionAttribute::Abstract);
+    if (isAbstract)
         str << "abstract ";
     str << "function '" << signature << "', " << why;
-    if (functionItem->isAbstract()) {
+    if (isAbstract) {
         str << "\nThis will lead to compilation errors due to not "
                "being able to instantiate the wrapper.";
     }
@@ -338,8 +356,9 @@ QString msgSkippingField(const VariableModelItem &field, const QString &classNam
 {
     QString result;
     QTextStream str(&result);
-    str << field->sourceLocation() << "skipping field '" << className
-        << "::" << field->name() << "' with unmatched type '" << type << '\'';
+    str << field->sourceLocation() << "skipping " << field->accessPolicy()
+        << " field '" << className << "::" << field->name()
+        << "' with unmatched type '" << type << '\'';
     return result;
 }
 
@@ -597,9 +616,10 @@ QString msgCannotFindDocumentation(const QString &fileName,
                                    const AbstractMetaEnum &e,
                                    const QString &query)
 {
-    return msgCannotFindDocumentation(fileName, "enum",
-                                      metaClass->name() + u"::"_s + e.name(),
-                                      query);
+    QString name = e.name();
+    if (metaClass != nullptr)
+        name.prepend(metaClass->name() + "::"_L1);
+    return msgCannotFindDocumentation(fileName, "enum", name, query);
 }
 
 QString msgCannotFindDocumentation(const QString &fileName,
@@ -607,9 +627,10 @@ QString msgCannotFindDocumentation(const QString &fileName,
                                    const AbstractMetaField &f,
                                    const QString &query)
 {
-    return msgCannotFindDocumentation(fileName, "field",
-                                      metaClass->name() + u"::"_s + f.name(),
-                                      query);
+    QString name = f.name();
+    if (metaClass != nullptr)
+        name.prepend(metaClass->name() + "::"_L1);
+    return msgCannotFindDocumentation(fileName, "field", name, query);
 }
 
 QString msgXpathDocModificationError(const DocModificationList& mods,
@@ -637,13 +658,13 @@ QString msgXpathDocModificationError(const DocModificationList& mods,
 
 QString msgCannotOpenForReading(const QFile &f)
 {
-    return QStringLiteral("Failed to open file '%1' for reading: %2")
+    return QString::fromLatin1("Failed to open file '%1' for reading: %2")
            .arg(QDir::toNativeSeparators(f.fileName()), f.errorString());
 }
 
 QString msgCannotOpenForWriting(const QFile &f)
 {
-    return QStringLiteral("Failed to open file '%1' for writing: %2")
+    return QString::fromLatin1("Failed to open file '%1' for writing: %2")
            .arg(QDir::toNativeSeparators(f.fileName()), f.errorString());
 }
 
