@@ -30,8 +30,8 @@
 
 using namespace Qt::StringLiterals;
 
-static const char ENABLE_PYSIDE_EXTENSIONS[] = "enable-pyside-extensions";
-static const char AVOID_PROTECTED_HACK[] = "avoid-protected-hack";
+static constexpr auto ENABLE_PYSIDE_EXTENSIONS = "enable-pyside-extensions"_L1;
+static constexpr auto AVOID_PROTECTED_HACK = "avoid-protected-hack"_L1;
 
 struct GeneratorOptions
 {
@@ -52,6 +52,9 @@ struct Generator::GeneratorPrivate
 
 GeneratorOptions Generator::GeneratorPrivate::m_options;
 
+// Kept as a variable for a potential Qt-in-namespace support
+QString Generator::m_gsp = "::"_L1;
+
 Generator::Generator() : m_d(new GeneratorPrivate)
 {
 }
@@ -89,9 +92,9 @@ bool Generator::setup(const ApiExtractorResult &api)
 QList<OptionDescription> Generator::options()
 {
     return {
-        {QLatin1StringView(AVOID_PROTECTED_HACK),
+        {AVOID_PROTECTED_HACK,
          u"Avoid the use of the '#define protected public' hack."_s},
-        {QLatin1StringView(ENABLE_PYSIDE_EXTENSIONS),
+        {ENABLE_PYSIDE_EXTENSIONS,
          u"Enable PySide extensions, such as support for signal/slots,\n"
           "use this if you are creating a binding for a Qt-based library."_s}
     };
@@ -112,9 +115,9 @@ bool GeneratorOptionsParser::handleBoolOption(const QString & key, OptionSource
 {
     if (source == OptionSource::CommandLineSingleDash)
         return false;
-    if (key == QLatin1StringView(ENABLE_PYSIDE_EXTENSIONS))
+    if (key == ENABLE_PYSIDE_EXTENSIONS)
         return ( m_options->usePySideExtensions = true);
-    if (key == QLatin1StringView(AVOID_PROTECTED_HACK))
+    if (key == AVOID_PROTECTED_HACK)
         return ( m_options->avoidProtectedHack = true);
     return false;
 }
@@ -308,9 +311,7 @@ QString Generator::getFullTypeName(TypeEntryCPtr type)
     QString result = type->qualifiedCppName();
     if (type->isArray())
         type = std::static_pointer_cast<const ArrayTypeEntry>(type)->nestedTypeEntry();
-    if (!isCppPrimitive(type))
-        result.prepend(u"::"_s);
-    return result;
+    return isCppPrimitive(type) ? result : addGlobalScopePrefix(result);
 }
 
 QString Generator::getFullTypeName(const AbstractMetaType &type)
@@ -320,7 +321,7 @@ QString Generator::getFullTypeName(const AbstractMetaType &type)
     if (type.isVoidPointer())
         return u"void*"_s;
     if (type.typeEntry()->isContainer())
-        return u"::"_s + type.cppSignature();
+        return addGlobalScopePrefix(type.cppSignature());
     QString typeName;
     if (type.typeEntry()->isComplex() && type.hasInstantiations())
         typeName = getFullTypeNameWithoutModifiers(type);
@@ -331,7 +332,9 @@ QString Generator::getFullTypeName(const AbstractMetaType &type)
 
 QString Generator::getFullTypeName(const AbstractMetaClassCPtr &metaClass)
 {
-    return u"::"_s + metaClass->qualifiedCppName();
+    const QString &qualName = metaClass->qualifiedCppName();
+    // Typedefs are generated into the global namespace
+    return metaClass->isTypeDef() ? qualName : addGlobalScopePrefix(qualName);
 }
 
 QString Generator::getFullTypeNameWithoutModifiers(const AbstractMetaType &type)
@@ -357,7 +360,7 @@ QString Generator::getFullTypeNameWithoutModifiers(const AbstractMetaType &type)
     }
     while (typeName.endsWith(u'*') || typeName.endsWith(u' '))
         typeName.chop(1);
-    return u"::"_s + typeName;
+    return addGlobalScopePrefix(typeName);
 }
 
 std::optional<DefaultValue>
@@ -645,6 +648,16 @@ QString Generator::subDirectoryForPackage(QString packageNameIn) const
     return packageNameIn;
 }
 
+QString Generator::addGlobalScopePrefix(const QString &t)
+{
+    return t.startsWith("std::"_L1) ? t : m_gsp + t;
+}
+
+QString Generator::globalScopePrefix(const GeneratorContext &classContext)
+{
+    return classContext.useWrapper() ? QString{} : m_gsp;
+}
+
 template<typename T>
 static QString getClassTargetFullName_(T t, bool includePackageName)
 {
